@@ -18,7 +18,10 @@ TRV_FULL_BATTERY_LEVEL = 3.0
 TRV_MIN_BATTERY_LEVEL = 2.5
 
 # Other Constants
-REST_TIMEOUT = 15
+REST_BACKOFF_FACTOR = 1
+REST_RETRIES = 3
+REST_TIMEOUT = 5
+
 
 
 # Text Values
